﻿using CoreModels.ModelsDepartment;
using DatabaseCore.Models.Security;
using ModuleTools.Extensions;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
    [DataContract]
	public class Lecturer : BaseEntity, IEntitySecurityExtenstion<Lecturer>, ILecturerModel
    {
        [DataMember]
        [Required]
        public Guid UserId { get; set; }

        [DataMember]
        public Guid? LecturerAcademicRankId { get; set; }

        [DataMember]
        public Guid? LecturerAcademicDegreeId { get; set; }

        [DataMember]
        [Required]
        public string LastName { get; set; }

        [DataMember]
        [Required]
        public string FirstName { get; set; }

        [DataMember]
        public string Patronymic { get; set; }

        [DataMember]
        public string Abbreviation { get; set; }

        [DataMember]
        [Required]
        public DateTime DateBirth { get; set; }

        [DataMember]
        [Required]
        public string Address { get; set; }

        [DataMember]
        [Required]
        public string Email { get; set; }

        [DataMember]
        [Required]
        public string MobileNumber { get; set; }

        [DataMember]
        public string HomeNumber { get; set; }

        [DataMember]
        public string Description { get; set; }

        [DataMember]
        public byte[] Photo { get; set; }

        [DataMember]
        public bool OnlyForPrivate { get; set; }

        [DataMember]
        public string GroupElectricalSafety { get; set; }

        //-------------------------------------------------------------------------

        public virtual User User { get; set; }

        public virtual LecturerAcademicRank LecturerAcademicRank { get; set; }

        public virtual LecturerAcademicDegree LecturerAcademicDegree { get; set; }

        //-------------------------------------------------------------------------

        [ForeignKey("LecturerId")]
        public virtual List<LecturerPost> LecturerPosts { get; set; }

        [ForeignKey("LecturerId")]
        public virtual List<EducationDirection> EducationDirections { get; set; }

        [ForeignKey("LecturerId")]
        public virtual List<StudentGroup> StudentGroups { get; set; }

        //-------------------------------------------------------------------------

        public Lecturer SecurityCheck(Lecturer entity, bool allowFullData)
        {
            if (!allowFullData)
            {
                entity.DateBirth = DateTime.Now;
                entity.Address = "скрыто";
                entity.Email = "скрыто";
                entity.MobileNumber = "скрыто";
                entity.HomeNumber = "скрыто";
                entity.Photo = null;
            }

            return entity;
        }

        public override string ToString() =>
            $"{LastName}{(FirstName.IsNotEmpty() ? $" {FirstName[0]}." : string.Empty)}{(Patronymic.IsNotEmpty() ? $"{Patronymic[0]}." : string.Empty)}";
    }
}