﻿using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий запись приказа по студенту
	/// </summary>
	[DataContract]
	[EntityDescription("OrderStudentRecord", "Запись приказа по студенту")]
	[EntityDependency("Order", "OrderId", "Приказ, к которому относится запись")]
	[EntityDependency("Student", "StudentId", "Студент, указанный в приказе")]
	[EntityDependency("StudentGroup", "StudentGroupFromId", "Из какой группы уходит студент")]
	[EntityDependency("StudentGroup", "StudentGroupToId", "В какую группу приходит студент")]
	public class OrderStudentRecord : BaseEntity, IEntitySecurityExtenstion<OrderStudentRecord>
	{
		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("OrderId")]
		public Guid OrderId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("StudentId")]
		public Guid StudentId { get; set; }

		[DataMember]
		[MapConfiguration("StudentGroupFromId")]
		public Guid? StudentGroupFromId { get; set; }

		[DataMember]
		[MapConfiguration("StudentGroupToId")]
		public Guid? StudentGroupToId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("OrderStudentMoveType")]
		public int OrderStudentMoveType { get; set; }

		[DataMember]
		[MapConfiguration("Info")]
		public string Info { get; set; }

		//-------------------------------------------------------------------------

		public virtual Order Order { get; set; }

		public virtual Student Student { get; set; }

		public virtual StudentGroup StudentGroupFrom { get; set; }

		public virtual StudentGroup StudentGroupTo { get; set; }

		//-------------------------------------------------------------------------

		//-------------------------------------------------------------------------

		public OrderStudentRecord SecurityCheck(OrderStudentRecord entity, bool allowFullData)
		{
			if (!allowFullData)
			{
				entity.Info = string.Empty;
				entity.OrderStudentMoveType = 0;
			}

			return entity;
		}

		public override string ToString() => $"{Student} {OrderStudentMoveType}";
	}
}