﻿using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий учебную группу кафедры
	/// </summary>
	[DataContract]
	[EntityDescription("StudentGroup", "Учебная группа кафедры")]
	[EntityDependency("EducationDirection", "EducationDirectionId", "Направление, по которому учится группа")]
	[EntityDependency("Lecturer", "LecturerId", "Куратор группы")]
	public class StudentGroup : BaseEntity, IEntitySecurityExtenstion<StudentGroup>
	{
		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("EducationDirectionId")]
		public Guid EducationDirectionId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("GroupNumber")]
		public int GroupNumber { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("AcademicCourse")]
		public int AcademicCourse { get; set; }

		[DataMember]
		[MapConfiguration("LecturerId")]
		public Guid? LecturerId { get; set; }

		//-------------------------------------------------------------------------

		public virtual EducationDirection EducationDirection { get; set; }

		public virtual Lecturer Lecturer { get; set; }

		//-------------------------------------------------------------------------

		[ForeignKey("StudentGroupId")]
		public virtual List<Student> Students { get; set; }

		[ForeignKey("StudentGroupFromId")]
		public virtual List<OrderStudentRecord> OrderStudentRecordFroms { get; set; }

		[ForeignKey("StudentGroupToId")]
		public virtual List<OrderStudentRecord> OrderStudentRecordTos { get; set; }

		//-------------------------------------------------------------------------

		public StudentGroup SecurityCheck(StudentGroup entity, bool allowFullData) => entity;

		public override string ToString() => $"{EducationDirection?.ShortName}-{AcademicCourse}{GroupNumber}";

		//-------------------------------------------------------------------------

		public int GetStudnetsByState(int state)
        {
			return Students?.Where(x => x.StudentState == state)?.Count() ?? 0;
        }
	}
}