﻿using DatabaseCore;
using DatabaseCore.Models.Department;
using DepartmentBusinessLogic.BindingModels;
using DepartmentBusinessLogic.Interfaces;
using DepartmentBusinessLogic.ViewModels;
using Microsoft.EntityFrameworkCore;
using ModuleTools.BusinessLogics;
using ModuleTools.Enums;
using ModuleTools.Models;
using System;
using System.Linq;

namespace DepartmentDatabaseImplementation.Implementations
{
    /// <summary>
    /// Реализация IOrderSyncHistoryRecordService
    /// </summary>
    public class OrderSyncHistoryRecordService : IOrderSyncHistoryRecordService
	{
		public OperationResultModel Create(OrderSyncHistoryRecordSetBindingModel model)
		{
			using var context = DatabaseManager.GetContext;

			var entity = Mapper.MapToClass<OrderSyncHistoryRecordSetBindingModel, OrderSyncHistoryRecord>(model, true);
			context.OrderSyncHistoryRecords.Add(entity);
			context.SaveChanges();
			return OperationResultModel.Success(Mapper.MapToClass<OrderSyncHistoryRecord, OrderSyncHistoryRecordViewModel>(entity, true));
		}

		public OperationResultModel Delete(OrderSyncHistoryRecordGetBindingModel model)
		{
			using var context = DatabaseManager.GetContext;
			var entity = context.OrderSyncHistoryRecords.FirstOrDefault(x => x.Id == model.Id);
			if (entity == null)
			{
				return OperationResultModel.Error("Error:", "Элемент не найден", ResultServiceStatusCode.NotFound);
			}
			context.OrderSyncHistoryRecords.Remove(entity);
			context.SaveChanges();

			return OperationResultModel.Success(true);
		}

		public OperationResultModel Read(OrderSyncHistoryRecordGetBindingModel model)
		{
			int countPages = 0;
			using var context = DatabaseManager.GetContext;

			// для одной записи
			if (model.Id.HasValue)
			{
				var entity = context.OrderSyncHistoryRecords.FirstOrDefault(x => x.Id == model.Id.Value);
				if (entity == null)
				{
					return OperationResultModel.Error("Error:", "Элемент не найден", ResultServiceStatusCode.NotFound);
				}
				return OperationResultModel.Success(Mapper.MapToClass<OrderSyncHistoryRecord, OrderSyncHistoryRecordViewModel>(entity, model.HaveRight));
			}

			var query = context.OrderSyncHistoryRecords.AsQueryable();

			if(model.OrderSyncHistoryId.HasValue)
			{
				query = query.Where(x => x.OrderSyncHistoryId == model.OrderSyncHistoryId.Value);
			}

			query = query.OrderByDescending(x => x.Information);

			query = query.Include(x => x.OrderSyncHistory);

			if (model.PageNumber.HasValue && model.PageSize.HasValue)
			{
				countPages = (int)Math.Ceiling((double)query.Count() / model.PageSize.Value);
				query = query
							.Skip(model.PageSize.Value * model.PageNumber.Value)
							.Take(model.PageSize.Value);
			}
			var result = new OrderSyncHistoryRecordListViewModel
			{
				MaxCount = countPages,
				List = query.Select(x => Mapper.MapToClass<OrderSyncHistoryRecord, OrderSyncHistoryRecordViewModel>(x, model.HaveRight)).ToList()
			};

			return OperationResultModel.Success(result);
		}

		public OperationResultModel Restore(OrderSyncHistoryRecordGetBindingModel model)
		{
			throw new NotImplementedException();
		}

		public OperationResultModel Update(OrderSyncHistoryRecordSetBindingModel model)
		{
			using var context = DatabaseManager.GetContext;

			var entity = context.OrderSyncHistoryRecords.FirstOrDefault(x => x.Id == model.Id);
			if (entity == null)
			{
				return OperationResultModel.Error("Error:", "Элемент не найден", ResultServiceStatusCode.NotFound);
			}
			entity = Mapper.MapToClass(model, entity, true);

			context.SaveChanges();

			return OperationResultModel.Success(Mapper.MapToClass<OrderSyncHistoryRecord, OrderSyncHistoryRecordViewModel>(entity, true));
		}
	}
}